@@ -209,7 +209,7 @@ class BaseExClient(HttpClient):
         coinexs: dict[str, CoinEx] = await self.coins()
         coins_db: dict[int, models.Coin] = {
             c.exid: (
-                await models.Coin.update_or_create({"scale": c.scale} if c.scale is not None else {}, ticker=c.ticker)
+                await models.Coin.update_or_create({"scale": c.scale or self.coin_scales[c.ticker]}, ticker=c.ticker)
             )[0]
             for c in coinexs.values()
         }
@@ -219,7 +219,7 @@ class BaseExClient(HttpClient):
                 coin=coins_db[c.exid],
                 ex=self.ex,
                 exid=c.exid,
-                minimum=c.minimum * 10**scl,
+                minimum=c.minimum and c.minimum * 10**scl,
             )
             for c in coinexs.values()
         ]
